@@ -7,7 +7,6 @@ import sys
 from O365 import Account, FileSystemTokenBackend
 from O365.connection import MSGraphProtocol
 from pathlib import Path
-from typing import Callable
 from urllib.parse import parse_qs, urlparse, unquote
 
 from rypython.ry365.sharepoint import Sharepoint
@@ -108,17 +107,17 @@ class O365Account(Account):
             site=site
         )
 
-    def get_folder_by_url(self, url: str, document_library_transform: Callable = None):
-        # url = unquote(link)
+    def get_folder_by_url(self, url: str, library_map: dict = None):
         site, lib_name, *folder_path = unquote(url).split('/')[4:]
-        account = O365Account(site=site)
-        # lib_name = lib_name.replace('Lex 30', 'Lex 3.0')
-        if document_library_transform:
-            lib_name = document_library_transform(lib_name)
         folder_path = '/'.join(folder_path)
+        if site != self.site.name:
+            return O365Account(site=site).get_folder_by_url(
+                url, library_map=library_map
+            )
+        lib_name = library_map.get(lib_name) if library_map else lib_name
         doc_library = self.get_document_library_by_name(
             lib_name
-        ) if lib_name != 'Shared Documents' else site.site.get_default_document_library()
+        ) if lib_name != 'Shared Documents' else self.site.get_default_document_library()
         return doc_library.get_item_by_path(folder_path)
 
     def get_document_library_by_name(self, document_library_name: str, site: str = None):
